# onnion

## Installation

```
$ pip3 install onnion
```

## Usage

```
$ onnion ssd-10-post.onnx -o ssd_post_model.py
```

See [tutorial](https://github.com/Idein/onnion/tree/master#tutorial).

## Development Guide

```
$ poetry install
```
